@@ -116,6 +116,22 @@ if((*copula)==43)
   free(out2);
 }
 
+// vectorized version
+void diff2PDF_mod_vec(double* u, double* v, int* n, double* par, double* par2, int* copula, double* out)
+{
+    int nn = 1;
+    double* ipars = (double *) malloc(2*sizeof(double));
+    for (int i = 0; i < (*n); ++i) {
+        if (copula[i] == 2) {
+            ipars[0] = par[i];
+            ipars[1] = par2[i];
+            diff2PDF_rho_tCopula(&u[i], &v[i], &nn, ipars, &copula[i], &out[i]);
+        } else {
+            diff2PDF_mod(&u[i], &v[i], &nn, &par[i], &copula[i], &out[i]);
+        }
+    };
+    free(ipars);
+}    
 
 ////////////////////////////////////////////////////////////////////
 //
@@ -429,6 +445,20 @@ if((*copula)==43)
   free(nparam);
 }
 
+// vectorized version
+void diff2PDF_u_mod_vec(double* u, double* v, int* n, double* par, double* par2, int* copula, double* out)
+{
+    int nn = 1;
+    double* ipars = (double *) malloc(2*sizeof(double));
+    
+    for (int i = 0; i < (*n); ++i) {
+        ipars[0] = par[i];
+        ipars[1] = par2[i];
+        diff2PDF_u_mod(&u[i], &v[i], &nn, ipars, &copula[i], &out[i]);
+    };
+    free(ipars);
+}
+
 //////////////////////////////////////////
 // Ableitung von c nach v (2 mal)
 // Second derivative with respect to v (two times)
@@ -506,7 +536,19 @@ if((*copula)==43)
   free(nparam);
 }
 
-
+// vectorized version
+void diff2PDF_v_mod_vec(double* u, double* v, int* n, double* par, double* par2, int* copula, double* out)
+{
+    int nn = 1;
+    double* ipars = (double *) malloc(2*sizeof(double));
+    
+    for (int i = 0; i < (*n); ++i) {
+        ipars[0] = par[i];
+        ipars[1] = par2[i];
+        diff2PDF_v_mod(&u[i], &v[i], &nn, ipars, &copula[i], &out[i]);
+    };
+    free(ipars);
+}
 
 ////////////////////////////////
 // Main function to calculate the derivative with respect to u
@@ -1074,6 +1116,24 @@ if((*copula)==43)
   free(nparam);
 }
 
+// vectorized version
+void diff2PDF_par_u_mod_vec(double* u, double* v, int* n, double* par, double* par2, int* copula, double* out)
+{
+    int nn = 1;
+    double* ipars = (double *) malloc(2*sizeof(double));
+    
+    for (int i = 0; i < (*n); ++i) {
+        ipars[0] = par[i];
+        ipars[1] = par2[i];
+        if (copula[i] == 2) {
+            diff2PDF_rho_u_tCopula_new(&u[i], &v[i], &nn, ipars, &copula[i], &out[i]);
+        } else {
+            diff2PDF_par_u_mod(&u[i], &v[i], &nn, ipars, &copula[i], &out[i]);
+        }
+    };
+    free(ipars);
+}
+
 
 void diff2PDF_par_u(double* u, double* v, int* n, double* param, int* copula, double* out)
 {
@@ -1380,3 +1440,21 @@ if((*copula)==43)
   free(nparam);
 }
 
+// vectorized version
+void diff2PDF_par_v_mod_vec(double* u, double* v, int* n, double* par, double* par2, int* copula, double* out)
+{
+    int nn = 1;
+    double* ipars = (double *) malloc(2*sizeof(double));
+    
+    for (int i = 0; i < (*n); ++i) {
+        ipars[0] = par[i];
+        ipars[1] = par2[i];
+        if (copula[i] == 2) {
+            diff2PDF_rho_v_tCopula_new(&u[i], &v[i], &nn, ipars, &copula[i], &out[i]);
+        } else {
+            diff2PDF_par_v_mod(&u[i], &v[i], &nn, ipars, &copula[i], &out[i]);
+        }
+    };
+    free(ipars);
+}
+
